//-----------------------------------------------------------------------------
#include "DeviceListCtrl.h"
#include "IPConfigureFrame.h"

BEGIN_EVENT_TABLE(DeviceListCtrl, wxListCtrl)
	EVT_LIST_DELETE_ALL_ITEMS(LIST_CTRL, DeviceListCtrl::OnDeleteAllItems)
	EVT_LIST_ITEM_SELECTED(LIST_CTRL, DeviceListCtrl::OnSelected)
	EVT_LIST_ITEM_DESELECTED(LIST_CTRL, DeviceListCtrl::OnDeselected)
	EVT_LIST_ITEM_RIGHT_CLICK(LIST_CTRL, DeviceListCtrl::OnItemRightClick)
	EVT_MENU(LIST_ASSIGN_TEMPORARY_IP, DeviceListCtrl::OnAssignTemporaryIP)
END_EVENT_TABLE()

//-----------------------------------------------------------------------------
DeviceListCtrl::DeviceListCtrl(wxWindow *parent, const wxWindowID id, const wxPoint& pos, const wxSize& size, long style, IPConfigureFrame* pParentFrame )
    : wxListCtrl(parent, id, pos, size, style), m_pParentFrame(pParentFrame), m_selectedItemID(-1) {}
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
void DeviceListCtrl::OnDeleteAllItems( wxListEvent& )
//-----------------------------------------------------------------------------
{
	m_selectedItemID = -1;
}

//-----------------------------------------------------------------------------
void DeviceListCtrl::OnDeselected( wxListEvent& e )
//-----------------------------------------------------------------------------
{
	m_selectedItemID = -1;
	if( m_pParentFrame )
	{
		m_pParentFrame->OnListItemDeselected( e.GetIndex() );
	}
}

//-----------------------------------------------------------------------------
void DeviceListCtrl::OnItemRightClick( wxListEvent& e )
//-----------------------------------------------------------------------------
{
	wxMenu menu(wxT(""));
	menu.Append( LIST_ASSIGN_TEMPORARY_IP, wxT("&Assign temporary IP"), wxEmptyString );
	PopupMenu( &menu, e.GetPoint() );
}

//-----------------------------------------------------------------------------
void DeviceListCtrl::OnAssignTemporaryIP( wxCommandEvent& )
//-----------------------------------------------------------------------------
{
	if( m_pParentFrame )
	{
		m_pParentFrame->AssignTemporaryIP( m_selectedItemID );
	}
}

//-----------------------------------------------------------------------------
void DeviceListCtrl::SetCurrentItemIndex( int index )
//-----------------------------------------------------------------------------
{
	m_selectedItemID = index;
	if( m_pParentFrame )
	{
		m_pParentFrame->OnListItemSelected( m_selectedItemID );
	}
}
